summaryrefslogtreecommitdiffstats
path: root/cc/active_animation.h
diff options
context:
space:
mode:
authorenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-19 21:22:42 +0000
committerenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-19 21:22:42 +0000
commitc753e25a8b4366c44134a8c21b9ed3392bf48608 (patch)
treef378c8a762caccf60856a1670ae33dfd638b9453 /cc/active_animation.h
parent503160f80568f024fa712e280bb1a4e1e6ca1ec3 (diff)
downloadchromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.zip
chromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.tar.gz
chromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.tar.bz2
Revert "cc: Rename cc classes and members to match filenames"
This reverts commit 184fac5add06d5f4670fa6be4a4d3b39232d51bb. git-svn-id: svn://svn.chromium.org/chrome/trunk/src@163059 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'cc/active_animation.h')
-rw-r--r--cc/active_animation.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/cc/active_animation.h b/cc/active_animation.h
index 01f3a27..b8d3607 100644
--- a/cc/active_animation.h
+++ b/cc/active_animation.h
@@ -10,12 +10,12 @@
namespace cc {
-class AnimationCurve;
+class CCAnimationCurve;
-// An ActiveAnimation, contains all the state required to play an AnimationCurve.
+// A CCActiveAnimation, contains all the state required to play a CCAnimationCurve.
// Specifically, the affected property, the run state (paused, finished, etc.),
// loop count, last pause time, and the total time spent paused.
-class ActiveAnimation {
+class CCActiveAnimation {
public:
// Animations begin in one of the 'waiting' states. Animations waiting for the next tick
// will start the next time the controller animates. Animations waiting for target
@@ -46,9 +46,9 @@ public:
TargetPropertyEnumSize
};
- static scoped_ptr<ActiveAnimation> create(scoped_ptr<AnimationCurve>, int animationId, int groupId, TargetProperty);
+ static scoped_ptr<CCActiveAnimation> create(scoped_ptr<CCAnimationCurve>, int animationId, int groupId, TargetProperty);
- virtual ~ActiveAnimation();
+ virtual ~CCActiveAnimation();
int id() const { return m_id; }
int group() const { return m_group; }
@@ -82,8 +82,8 @@ public:
|| m_runState == Aborted
|| m_runState == WaitingForDeletion; }
- AnimationCurve* curve() { return m_curve.get(); }
- const AnimationCurve* curve() const { return m_curve.get(); }
+ CCAnimationCurve* curve() { return m_curve.get(); }
+ const CCAnimationCurve* curve() const { return m_curve.get(); }
// If this is true, even if the animation is running, it will not be tickable until
// it is given a start time. This is true for animations running on the main thread.
@@ -99,16 +99,16 @@ public:
NonControllingInstance
};
- scoped_ptr<ActiveAnimation> clone(InstanceType) const;
- scoped_ptr<ActiveAnimation> cloneAndInitialize(InstanceType, RunState initialRunState, double startTime) const;
+ scoped_ptr<CCActiveAnimation> clone(InstanceType) const;
+ scoped_ptr<CCActiveAnimation> cloneAndInitialize(InstanceType, RunState initialRunState, double startTime) const;
bool isControllingInstance() const { return m_isControllingInstance; }
- void pushPropertiesTo(ActiveAnimation*) const;
+ void pushPropertiesTo(CCActiveAnimation*) const;
private:
- ActiveAnimation(scoped_ptr<AnimationCurve>, int animationId, int groupId, TargetProperty);
+ CCActiveAnimation(scoped_ptr<CCAnimationCurve>, int animationId, int groupId, TargetProperty);
- scoped_ptr<AnimationCurve> m_curve;
+ scoped_ptr<CCAnimationCurve> m_curve;
// IDs are not necessarily unique.
int m_id;
@@ -146,14 +146,14 @@ private:
// Animations lead dual lives. An active animation will be conceptually owned by
// two controllers, one on the impl thread and one on the main. In reality, there
// will be two separate ActiveAnimation instances for the same animation. They
// will have the same group id and the same target property (these two values
// uniquely identify an animation). The instance on the impl thread is the instance
// that ultimately controls the values of the animating layer and so we will refer
// to it as the 'controlling instance'.
bool m_isControllingInstance;
- DISALLOW_COPY_AND_ASSIGN(ActiveAnimation);
+ DISALLOW_COPY_AND_ASSIGN(CCActiveAnimation);
};
} // namespace cc
@@ -146,14 +146,14 @@ private:
// Animations lead dual lives. An active animation will be conceptually owned by
// two controllers, one on the impl thread and one on the main. In reality, there
- // will be two separate ActiveAnimation instances for the same animation. They
+ // will be two separate CCActiveAnimation instances for the same animation. They
// will have the same group id and the same target property (these two values
// uniquely identify an animation). The instance on the impl thread is the instance